@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.7.1';
+$Git::Hooks::VERSION = '1.8.0';
 use 5.010;
 use strict;
 use warnings;
@@ -18,7 +18,7 @@ BEGIN {                ## no critic (Subroutines::RequireArgUnpacking)
             PRE_COMMIT PREPARE_COMMIT_MSG COMMIT_MSG
             POST_COMMIT PRE_REBASE POST_CHECKOUT POST_MERGE
             PRE_PUSH PRE_RECEIVE UPDATE POST_RECEIVE POST_UPDATE
-            PRE_AUTO_GC POST_REWRITE
+            PUSH_TO_CHECKOUT PRE_AUTO_GC POST_REWRITE
 
             REF_UPDATE PATCHSET_CREATED DRAFT_PUBLISHED
           /;
@@ -692,7 +692,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.7.1
+version 1.8.0
 
 =head1 SYNOPSIS
 
@@ -954,6 +954,11 @@ Integrate Git with the L<JIRA|http://www.atlassian.com/software/jira/>
 ticketing system by requiring that every commit message cites valid
 JIRA issues.
 
+=item * Git::Hooks::CheckCommit
+
+Check various aspects of commits like author and committer names and emails,
+and signatures.
+
 =item * Git::Hooks::CheckLog
 
 Check commit log messages formatting.
@@ -1487,6 +1492,10 @@ C<Git::More::get_affected_ref_rage> methods.
 
 =item * POST_UPDATE(GIT, updated-ref-name, ...)
 
+=item * PUSH_TO_CHECKOUT(GIT, SHA1)
+
+The C<push-to-checkout> hook was introduced in Git 2.4.
+
 =item * PRE_AUTO_GC(GIT)
 
 =item * POST_REWRITE(GIT, command)
